/*------------------------------------------------------*/
/* dio96.h			    			*/
/* 		by Tim Edwards 				*/
/*							*/
/* Written January 1999 for NICB-DIO96 board		*/
/* Modified December 20, 2000, eliminates port# as part	*/
/* of ioctl definition; determined by device instead.	*/
/* Corresponds to dio96 driver versions 2.1 and later.	*/
/*------------------------------------------------------*/

/*--------------------------------------------------------------*/
/* ioctl() commands:                                            */
/*--------------------------------------------------------------*/
/* bits: gmmc cbbb                                         	*/
/*--------------------------------------------------------------*/
/* s = set/get (0 = get, 1 = set)                               */
/* m = mode (0 = bit clear (with s=1), 1 = mode,		*/
/*	     2 = byte op, 3 = bit op (get or set)		*/
/* c = channel (0 = A, 1 = B, 2 = C, 3 = (not used))            */
/* b = bit (0 to 7)                                             */
/*--------------------------------------------------------------*/

#define SET_MODE	0xa0
#define GET_MODE	0x20

#define SET_A	0xc0
#define SET_B	0xc8
#define SET_C	0xd0
#define GET_A	0x40
#define GET_B	0x48
#define GET_C	0x50

/* ioctl() bit-level calls to 82C55 pins */

#define SET_A0	0xe0
#define SET_A1	0xe1
#define SET_A2	0xe2
#define SET_A3	0xe3
#define SET_A4	0xe4
#define SET_A5	0xe5
#define SET_A6	0xe6
#define SET_A7	0xe7
#define SET_B0	0xe8
#define SET_B1	0xe9
#define SET_B2	0xea
#define SET_B3	0xeb
#define SET_B4	0xec
#define SET_B5	0xed
#define SET_B6	0xee
#define SET_B7	0xef
#define SET_C0	0xf0
#define SET_C1	0xf1
#define SET_C2	0xf2
#define SET_C3	0xf3
#define SET_C4	0xf4
#define SET_C5	0xf5
#define SET_C6	0xf6
#define SET_C7	0xf7

#define CLR_A0	0x80
#define CLR_A1	0x81
#define CLR_A2	0x82
#define CLR_A3	0x83
#define CLR_A4	0x84
#define CLR_A5	0x85
#define CLR_A6	0x86
#define CLR_A7	0x87
#define CLR_B0	0x88
#define CLR_B1	0x89
#define CLR_B2	0x8a
#define CLR_B3	0x8b
#define CLR_B4	0x8c
#define CLR_B5	0x8d
#define CLR_B6	0x8e
#define CLR_B7	0x8f
#define CLR_C0	0x90
#define CLR_C1	0x91
#define CLR_C2	0x92
#define CLR_C3	0x93
#define CLR_C4	0x94
#define CLR_C5	0x95
#define CLR_C6	0x96
#define CLR_C7	0x97

#define GET_A0	0x60
#define GET_A1	0x61
#define GET_A2	0x62
#define GET_A3	0x63
#define GET_A4	0x64
#define GET_A5	0x65
#define GET_A6	0x66
#define GET_A7	0x67
#define GET_B0	0x68
#define GET_B1	0x69
#define GET_B2	0x6a
#define GET_B3	0x6b
#define GET_B4	0x6c
#define GET_B5	0x6d
#define GET_B6	0x6e
#define GET_B7	0x6f
#define GET_C0	0x70
#define GET_C1	0x71
#define GET_C2	0x72
#define GET_C3	0x73
#define GET_C4	0x74
#define GET_C5	0x75
#define GET_C6	0x76
#define GET_C7	0x77

/*---------------------------------------------------------------*/
/* Control Register values for use with DIO_SET_MODE ioctl call. */
/*---------------------------------------------------------------*/

#define OUTPUT		0x00

/* input modes */

#define CNTL_A		0x10
#define CNTL_B		0x02
#define CNTL_CL		0x01
#define CNTL_CH		0x08
#define CNTL_C		0x09	/* CNTL_C = CNTL_CL | CNTL_CH */
#define MODE_SET	0x80	/* set by driver---shouldn't be needed */

/*--------------------------------------------------------------*/
/* 82C55 modes 							*/
/* GRPA controls mode of ports A and CU 			*/
/* GRPB controls mode of ports B and CL 			*/
/* Default setting on opening the device is Mode 0 (Normal I/O) */
/*      for both groups 					*/
/*--------------------------------------------------------------*/

#define GRPA_MODE0 0x00		/* Normal I/O 		*/
#define GRPA_MODE1 0x20		/* Strobed I/O 		*/
#define GRPA_MODE2 0x40		/* Bi-directional Bus 	*/
#define GRPB_MODE0 0x00		/* Normal I/O 		*/
#define GRPB_MODE1 0x04		/* Strobed I/O		*/

/*--------------------------------------------------------------*/
/* Mode 1 bit definitions (port C only)				*/
/*--------------------------------------------------------------*/

#define OBFA		0x80
#define INTE1		0x40
#define IBFA		0x20
#define INTE2		0x10
#define INTRA		0x08
#define INTEB		0x04
#define IBFB		0x02
#define INTRB		0x01

/*--------------------------------------------------------------*/
/* 82C54 timer/counter modes and interrupt control		*/
/*--------------------------------------------------------------*/

#define COUNTER0   	0x00		/* Access counter 0 */
#define COUNTER1   	0x40		/* Access counter 1 */
#define ACCESS_LSB 	0x10
#define ACCESS_MSB 	0x20
#define ACCESS_BOTH	0x30
#define LATCH_COUNTER	0x00
#define CNTR_BCD	0x01
#define CNTR_BINARY	0x00
#define CNTR_MODE0	0x00
#define CNTR_MODE1	0x02
#define CNTR_MODE2	0x04
#define CNTR_MODE3	0x06
#define AIRQ0		0x00
#define AIRQ1		0x02
#define BIRQ0		0x04
#define BIRQ1		0x08
#define CIRQ0		0x10
#define CIRQ1		0x20
#define DIRQ0		0x40
#define DIRQ1		0x80
#define INTEN		0x04
#define CTRIRQ		0x02
#define CTR1		0x01

/*--------------------------------------------------------------*/
